==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/sites/lang/sites_he.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/sites?lang_cible=he
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_echec_syndication_01' => 'נכשלה הסינדיקציה :את  הbackend אי אפשר לפענח או אינו כולל שום מאמר.',
	'avis_echec_syndication_02' => 'נכשלה הסינדיקציה : אי אפשר להיכנס לbackend של האתר',
	'avis_site_introuvable' => 'אתר לא נמצא',
	'avis_site_syndique_probleme' => 'אזהרה: הסינדיקציה של האתר הזה נתקלה בבעיה; כתוצאה מכך המערכת מנותקת זמנית. נא אשר את הכתובת של קובץ הסינדיקציה של האתר הזה(<b>@url_syndic@</b>), ונסה עוד פעם לבצע החזרה חדשה של האינפורמציה',
	'avis_sites_probleme_syndication' => '.האתרים האלה נתקלו בבעיית סינדיקציה ',
	'avis_sites_syndiques_probleme' => 'אתרי הסינדיקציה האלה יצרו בעיה',

	// B
	'bouton_radio_modere_posteriori' => 'צמצום לאחר מכן', # MODIF
	'bouton_radio_modere_priori' => 'צמצום מראש', # MODIF
	'bouton_radio_non_syndication' => 'אין סינדיקציה',
	'bouton_radio_syndication' => ':סינדיקציה',

	// E
	'entree_adresse_fichier_syndication' => 'כתובת קובץ הסינדיקציה :',
	'entree_adresse_site' => '<b>כתובת האתר</b> [Obligatoire]',
	'entree_description_site' => 'תיאור האתר',

	// F
	'form_prop_nom_site' => 'שם האתר',

	// I
	'icone_modifier_site' => 'שנה את האתר הזה',
	'icone_referencer_nouveau_site' => 'ייחס אתר חדש',
	'icone_voir_sites_references' => 'הצג אתרים עם מראי מקום',
	'info_a_valider' => '[לאישור]',
	'info_bloquer' => 'חסום',
	'info_bloquer_lien' => 'חסום את הקישור הזה',
	'info_derniere_syndication' => 'הסינדיקציה האחרונה של האתר הזה בוצעה',
	'info_liens_syndiques_1' => 'קישורים עם סינדיקציה',
	'info_liens_syndiques_2' => '.מחכה למתן תוקף חוקי',
	'info_panne_site_syndique' => 'אתר עם סינדיקציה מקולקל',
	'info_probleme_grave' => 'שגיאה של',
	'info_question_proposer_site' => '?מי יכול להציע אתרים עם מראי מקום',
	'info_retablir_lien' => 'החזרת קישור זה',
	'info_site_attente' => 'האתר בציפיית הוולידציה',
	'info_site_reference' => 'מראי מקום אתרים מקוונים',
	'info_site_refuse' => 'האתר נדחה',
	'info_site_valider' => 'אתרים כדי לאמת',
	'info_sites_referencer' => 'הוספת אתר למראי מקום',
	'info_statut_site_1' => 'אתר זה :',
	'info_statut_site_2' => 'לאור',
	'info_statut_site_3' => 'המוצעת',
	'info_statut_site_4' => 'לפח', # MODIF
	'info_syndication' => 'סינדיקציה:',
	'info_syndication_articles' => 'מאמר(ים)',

	// T
	'texte_syndication' => 'Il est possible de récupérer automatiquement, lorsqu’un site Web le permet, 
		la liste de ses nouveautés. Pour cela, vous devez activer la syndication. 
		<blockquote><i>Certains hébergeurs désactivent cette fonctionnalité ; 
		dans ce cas, vous ne pourrez pas utiliser la syndication de contenu
		depuis votre site.</i></blockquote>' # MODIF
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/sites/lang/sites_he.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/sites?lang_cible=he
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_echec_syndication_01' => 'נכשלה הסינדיקציה :את  הbackend אי אפשר לפענח או אינו כולל שום מאמר.',
	'avis_echec_syndication_02' => 'נכשלה הסינדיקציה : אי אפשר להיכנס לbackend של האתר',
	'avis_site_introuvable' => 'אתר לא נמצא',
	'avis_site_syndique_probleme' => 'אזהרה: הסינדיקציה של האתר הזה נתקלה בבעיה; כתוצאה מכך המערכת מנותקת זמנית. נא אשר את הכתובת של קובץ הסינדיקציה של האתר הזה(<b>@url_syndic@</b>), ונסה עוד פעם לבצע החזרה חדשה של האינפורמציה',
	'avis_sites_probleme_syndication' => '.האתרים האלה נתקלו בבעיית סינדיקציה ',
	'avis_sites_syndiques_probleme' => 'אתרי הסינדיקציה האלה יצרו בעיה',

	// B
	'bouton_radio_modere_posteriori' => 'צמצום לאחר מכן', # MODIF
	'bouton_radio_modere_priori' => 'צמצום מראש', # MODIF
	'bouton_radio_non_syndication' => 'אין סינדיקציה',
	'bouton_radio_syndication' => ':סינדיקציה',

	// E
	'entree_adresse_fichier_syndication' => 'כתובת קובץ הסינדיקציה :',
	'entree_adresse_site' => '<b>כתובת האתר</b> [Obligatoire]',
	'entree_description_site' => 'תיאור האתר',

	// F
	'form_prop_nom_site' => 'שם האתר',

	// I
	'icone_modifier_site' => 'שנה את האתר הזה',
	'icone_referencer_nouveau_site' => 'ייחס אתר חדש',
	'icone_voir_sites_references' => 'הצג אתרים עם מראי מקום',
	'info_1_site' => 'אתר 1',
	'info_a_valider' => '[לאישור]',
	'info_bloquer' => 'חסום',
	'info_bloquer_lien' => 'חסום את הקישור הזה',
	'info_derniere_syndication' => 'הסינדיקציה האחרונה של האתר הזה בוצעה',
	'info_liens_syndiques_1' => 'קישורים עם סינדיקציה',
	'info_liens_syndiques_2' => '.מחכה למתן תוקף חוקי',
	'info_panne_site_syndique' => 'אתר עם סינדיקציה מקולקל',
	'info_probleme_grave' => 'שגיאה של',
	'info_question_proposer_site' => '?מי יכול להציע אתרים עם מראי מקום',
	'info_retablir_lien' => 'החזרת קישור זה',
	'info_site_attente' => 'האתר בציפיית הוולידציה',
	'info_site_reference' => 'מראי מקום אתרים מקוונים',
	'info_site_refuse' => 'האתר נדחה',
	'info_site_valider' => 'אתרים כדי לאמת',
	'info_sites_referencer' => 'הוספת אתר למראי מקום',
	'info_statut_site_1' => 'אתר זה :',
	'info_statut_site_2' => 'לאור',
	'info_statut_site_3' => 'המוצעת',
	'info_statut_site_4' => 'לפח', # MODIF
	'info_syndication' => 'סינדיקציה:',
	'info_syndication_articles' => 'מאמר(ים)',

	// T
	'texte_syndication' => 'Il est possible de récupérer automatiquement, lorsqu’un site Web le permet, 
		la liste de ses nouveautés. Pour cela, vous devez activer la syndication. 
		<blockquote><i>Certains hébergeurs désactivent cette fonctionnalité ; 
		dans ce cas, vous ne pourrez pas utiliser la syndication de contenu
		depuis votre site.</i></blockquote>' # MODIF
);

?>
